import os
from tempfile import TemporaryDirectory

from setuptools_gettext import gather_built_files, lang_from_dir, parse_lang


def test_lang_from_dir():
    with TemporaryDirectory() as td:
        podir = os.path.join(td, "po")
        os.mkdir(podir)
        with open(os.path.join(podir, "de.po"), "w") as f:
            f.write("foo")
        with open(os.path.join(podir, "fr.po"), "w") as f:
            f.write("foo")
        with open(os.path.join(podir, "de_DE.po"), "w") as f:
            f.write("foo")

        assert set(lang_from_dir(podir)) == {"de", "de_DE", "fr"}


def test_parse_lang():
    assert parse_lang("de") == ["de"]
    assert parse_lang("de_DE,de") == ["de_DE", "de"]


def test_gather_built_files():
    with TemporaryDirectory() as td:
        builddir = os.path.join(td, "po")
        os.mkdir(builddir)
        dedir = os.path.join(builddir, "de")
        os.mkdir(dedir)
        de_lc_messages_dir = os.path.join(dedir, "LC_MESSAGES")
        os.mkdir(de_lc_messages_dir)
        with open(os.path.join(de_lc_messages_dir, "app.mo"), "w") as f:
            f.write("foo")
        with open(os.path.join(de_lc_messages_dir, "app2.mo"), "w") as f:
            f.write("foo")
        assert set(gather_built_files(builddir)) == {
            os.path.join(de_lc_messages_dir, "app.mo"),
            os.path.join(de_lc_messages_dir, "app2.mo"),
        }



import os
import shutil
from tempfile import TemporaryDirectory
from unittest import SkipTest

from setuptools import Distribution

from setuptools_gettext import (
    build_mo,
    install_mo,
    load_pyproject_config,
    update_pot,
)


def test_example_build():
    with TemporaryDirectory() as td:
        shutil.copytree("example", td + "/example")

        old_cwd = os.getcwd()

        dist = Distribution()

        load_pyproject_config(dist, {})

        os.chdir(td + "/example")
        try:
            cmd = build_mo(dist)
            cmd.initialize_options()
            cmd.finalize_options()
            cmd.run()
        finally:
            os.chdir(old_cwd)


def test_example_install():
    with TemporaryDirectory() as td, TemporaryDirectory() as root:
        shutil.copytree("example", td + "/example")

        dist = Distribution()

        load_pyproject_config(dist, {})

        old_cwd = os.getcwd()

        os.chdir(td + "/example")
        try:
            cmd = install_mo(dist)
            cmd.initialize_options()
            cmd.root = root  # type: ignore
            cmd.finalize_options()
            cmd.run()
        finally:
            os.chdir(old_cwd)


def test_update_pot():
    # Skip this test if xgettext is not available
    if shutil.which("xgettext") is None:
        raise SkipTest("xgettext not available")
    with TemporaryDirectory() as td:
        shutil.copytree("example", td + "/example")
        p = os.path.join(td, "example", "hallowereld", "example.py")
        with open(p, "w") as f:
            f.write('# Use the "_" shorthand for gettext\n')
            f.write("from gettext import gettext as _\n")
            f.write('print(_("Hello Example"))')

        dist = Distribution(
            attrs={
                "name": "hallowereld",
            }
        )

        load_pyproject_config(dist, {})

        old_cwd = os.getcwd()
        os.chdir(os.path.join(td, "example"))
        try:
            cmd = update_pot(dist)
            cmd.initialize_options()
            cmd.finalize_options()
            cmd.run()
        finally:
            os.chdir(old_cwd)
        with open(os.path.join(td, "example", "po", "hallowereld.pot")) as f:
            assert "Hello Example" in f.read()
